



if not exist "%LIBRARY_PREFIX%\mingw-w64\bin\libsmumps.dll" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_PREFIX%\mingw-w64\bin\libdmumps.dll" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_PREFIX%\mingw-w64\bin\libcmumps.dll" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_PREFIX%\mingw-w64\bin\libzmumps.dll" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_PREFIX%\mingw-w64\lib\libmumps_common.a" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_PREFIX%\mingw-w64\lib\libpord.a" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_PREFIX%\mingw-w64\include\dmumps_struc.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
